@@ -3,7 +3,7 @@
 import zope.component.interfaces
 from dolmen.field import GlobalClass
 from zope.schema import TextLine
-from zope.interface import Interface, Attribute
+from zope.interface import Attribute
 from zope.annotation.interfaces import IAttributeAnnotatable
 
 
@@ -11,14 +11,13 @@ class IBaseContent(IAttributeAnnotatable):
     """Marker interface for dolmen base content.
     """
     title = TextLine(
-        title = u"Title",
-        required = True
+        title=u"Title",
+        required=True,
         )
-    
+
     __content_type__ = Attribute(
         """Type of the object. Usually set by the grokker, using the
-        grok.name directive."""
-        )
+        grok.name directive.""")
 
 
 class IContent(IBaseContent):
@@ -30,6 +29,7 @@ class IContainer(IBaseContent):
     """Marker interface for folderish dolmen objects.
     """
 
+
 class IOrderedContainer(IContainer):
     """Marker interface for folderish dolmen objects with ordered keys.
     """
@@ -39,21 +39,21 @@ class IFactory(zope.component.interfaces.IFactory):
     """A factory for a dolmen content type.
     """
     factory = GlobalClass(
-        required = True,
-        title = u"Class used as a factory",
-        schema = IBaseContent
+        required=True,
+        title=u"Class used as a factory",
+        schema=IBaseContent,
         )
 
     addform = TextLine(
-        required = True,
-        title = u"Name of the add form",
-        default = u"dolmen.add"
+        required=True,
+        title=u"Name of the add form",
+        default=u"dolmen.add",
         )
 
     description = TextLine(
-        required = True,
-        title = u"Description of the added content",
-        default = u""
+        required=True,
+        title=u"Description of the added content",
+        default=u"",
         )
 
     def getSchema():
@@ -62,7 +62,8 @@ class IFactory(zope.component.interfaces.IFactory):
         by the instance of the object issued from the factory.
         """
 
+
 __all__ = (
     'IBaseContent', 'IContent',
-    'IContainer', 'IOrderedContainer', 'IFactory'
+    'IContainer', 'IOrderedContainer', 'IFactory',
     )
